@@ -21,7 +21,7 @@
  *  OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
  *  WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  *
- *  $Id: dashboard-frontend-xmlwriter.c,v 1.4.2.2 2005/01/20 15:41:34 chpe Exp $
+ *  $Id: dashboard-frontend-xmlwriter.c,v 1.5 2004/09/26 16:07:58 chpe Exp $
  */
 
 #include "dashboard-frontend-xmlwriter.h"
@@ -163,17 +163,17 @@ NewTextWriterDashboard (const xmlChar *frontend,
 	ret = xmlTextWriterStartDocument (writer, NULL, NULL, NULL);
 	if (ret < 0) goto error;
 
-	ret = xmlTextWriterStartElement (writer, (const xmlChar*) "CluePacket");
+	ret = xmlTextWriterStartElement (writer, "CluePacket");
 	if (ret < 0) goto error;
 
-	ret = xmlTextWriterWriteElement (writer, (const xmlChar*) "Frontend", frontend);
+	ret = xmlTextWriterWriteElement (writer, "Frontend", frontend);
 	if (ret < 0) goto error;
 
-	ret = xmlTextWriterWriteElement (writer, (const xmlChar*) "Context", context);
+	ret = xmlTextWriterWriteElement (writer, "Context", context);
 	if (ret < 0) goto error;
 
-	ret = xmlTextWriterWriteElement (writer, (const xmlChar*) "Focused",
-					 focused ? (const xmlChar*) "true" : (const xmlChar*) "false");
+	ret = xmlTextWriterWriteElement (writer, "Focused",
+					 focused ? "true" : "false");
 	if (ret < 0) goto error;
 
 error:
@@ -216,13 +216,13 @@ DashboardSendClue (xmlTextWriterPtr writer,
 	if (!writer)
 		return -1;
 
-	ret = xmlTextWriterStartElement (writer, (const xmlChar*) "Clue");
+	ret = xmlTextWriterStartElement (writer, "Clue");
 	if (ret < 0) return ret;
 
-	ret = xmlTextWriterWriteAttribute (writer, (const xmlChar*) "Type", type);
+	ret = xmlTextWriterWriteAttribute (writer, "Type", type);
 	if (ret < 0) return ret;
 
-	ret = xmlTextWriterWriteFormatAttribute (writer, (const xmlChar*) "Relevance", "%d", relevance);
+	ret = xmlTextWriterWriteFormatAttribute (writer, "Relevance", "%d", relevance);
 	if (ret < 0) return ret;
 
 	ret = xmlTextWriterWriteString (writer, text);
