@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id$
+ *  $Id: ephy-sidebar-extension.c,v 1.3 2004/10/26 20:42:35 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -37,9 +37,9 @@
 #include <epiphany/ephy-session.h>
 #include <epiphany/ephy-node.h>
 #include <epiphany/ephy-node-db.h>
+#include <epiphany/ephy-state.h>
 
 #include "ephy-file-helpers.h"
-#include "ephy-state.h"
 #include "ephy-debug.h"
 
 #include <gtk/gtkactiongroup.h>
@@ -48,6 +48,7 @@
 #include <gtk/gtktoggleaction.h>
 #include <gtk/gtkhpaned.h>
 #include <gtk/gtkdialog.h>
+#include <gtk/gtkmessagedialog.h>
 #include <gtk/gtkstock.h>
 #include <gtk/gtkhbox.h>
 #include <gtk/gtkimage.h>
@@ -100,7 +101,7 @@ typedef struct
 } WindowData;
 
 static void cmd_view_sidebar	(GtkAction *action,
-				 WindowData *data);
+				 EphyWindow *window);
 
 static GtkToggleActionEntry toggle_action_entries [] =
 {
@@ -167,15 +168,23 @@ ephy_sidebar_extension_register_type (GTypeModule *module)
 }
 
 static void 
-cmd_view_sidebar (GtkAction *action,
-		  WindowData *data)
+cmd_view_sidebar (GtkAction *action, EphyWindow *window)
 {
 	GValue value = { 0, };
+	gboolean ppview_mode;
+	WindowData *data;
+
+	data = (WindowData *) g_object_get_data (G_OBJECT (window), WINDOW_DATA_KEY);
+
+	g_object_get (window, "print-preview-mode", &ppview_mode, NULL);
 	g_value_init (&value, G_TYPE_BOOLEAN);
 
 	if (gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action)))
 	{
-		gtk_widget_show (data->sidebar);
+		if (!ppview_mode)
+		{
+			gtk_widget_show (data->sidebar);
+		}
 		g_value_set_boolean (&value, TRUE);
 	}
 	else
@@ -189,6 +198,26 @@ cmd_view_sidebar (GtkAction *action,
 	g_value_unset (&value);
 }
 
+static void
+window_ppv_mode_notify_cb (EphyWindow *window, GParamSpec   *pspec,
+                           WindowData *data)
+{
+	GtkAction *action;
+	gboolean ppview_mode;
+
+	g_object_get (window, "print-preview-mode", &ppview_mode, NULL);
+	action = gtk_action_group_get_action (data->action_group, "ViewSidebar");
+
+	if (ppview_mode)
+	{
+		gtk_widget_hide (data->sidebar);
+	}
+	else if (gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action)))
+	{
+		gtk_widget_show (data->sidebar);
+	}
+}
+
 static void
 sidebar_page_changed_cb (GtkWidget* sidebar,
 			 const char * page_id, 
@@ -309,7 +338,7 @@ add_dialog_response_cb (GtkDialog *dialog,
 			int response, 
 			struct ResponseCallbackData *data)
 {
-	if (response == GTK_RESPONSE_OK)
+	if (response == GTK_RESPONSE_ACCEPT)
 	{
 		EphyNode *node;
 		GValue value = { 0, };
@@ -340,8 +369,6 @@ impl_add_sidebar (EphySidebarExtension *extension,
 	EphySession *session;
 	EphyWindow *window;
 	GtkWidget *dialog;
-	GtkWidget *hbox, *vbox, *label, *image;
-	char *text, *primary;
 	struct ResponseCallbackData *cb_data;
 	int i;
 	
@@ -361,48 +388,23 @@ impl_add_sidebar (EphySidebarExtension *extension,
 	session = EPHY_SESSION (ephy_shell_get_session (ephy_shell));
 	window = ephy_session_get_active_window (session);
 
-	dialog = gtk_dialog_new_with_buttons ("",
-					      GTK_WINDOW (window),
-					      GTK_DIALOG_NO_SEPARATOR,
-					      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					      _("_Add Sidebar"), GTK_RESPONSE_OK,
-					      NULL);
-	
-	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 14);
+	dialog = gtk_message_dialog_new
+		(GTK_WINDOW (window),
+		 GTK_DIALOG_DESTROY_WITH_PARENT,
+		 GTK_MESSAGE_QUESTION,
+		 GTK_BUTTONS_CANCEL,
+		 _("Add \"%s\" to the Sidebar?"), title);
 
-	hbox = gtk_hbox_new (FALSE, 6);
-	gtk_widget_show (hbox);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox,
-			    TRUE, TRUE, 0);
+	gtk_message_dialog_format_secondary_text
+		(GTK_MESSAGE_DIALOG (dialog),
+		 _("The source to the new sidebar page is %s."), url);
 
-	image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_WARNING,
-					  GTK_ICON_SIZE_DIALOG);
-	gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
-	gtk_widget_show (image);
-	gtk_box_pack_start (GTK_BOX (hbox), image, TRUE, TRUE, 0);
+	gtk_window_set_title (GTK_WINDOW (dialog), _("Add Sidebar"));
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
 
-	vbox = gtk_vbox_new (FALSE, 6);
-	gtk_widget_show (vbox);
-	gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
-
-	label = gtk_label_new (NULL);
-	gtk_label_set_selectable (GTK_LABEL (label), TRUE);
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
-
-	primary = g_markup_printf_escaped (_("Add \"%s\" to the Sidebar?"), title);
-
-	text = g_strdup_printf ("<span weight=\"bold\" size=\"larger\">%s</span>\n\n%s\n<tt>%s</tt>",
-				primary, _("The source to the new sidebar page is:"), url);
-
-	gtk_label_set_markup (GTK_LABEL (label), text);
-	g_free (text);
-	g_free (primary);
-
-	gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, TRUE, 0);
-	gtk_widget_show (label);
+	gtk_dialog_add_button (GTK_DIALOG (dialog),
+			       _("_Add Sidebar"), GTK_RESPONSE_ACCEPT);
+	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
 
 	cb_data = g_new (struct ResponseCallbackData, 1);
 	cb_data->url = g_strdup (url);
@@ -435,7 +437,7 @@ impl_attach_window (EphyExtension *ext,
 
 	LOG ("EphySidebarExtension attach_window")
 	
-	manager = GTK_UI_MANAGER (window->ui_merge);
+	manager = GTK_UI_MANAGER (ephy_window_get_ui_manager (window));
 
 	data = g_new (WindowData, 1);
 	g_object_set_data_full (G_OBJECT (window), WINDOW_DATA_KEY, data,
@@ -450,7 +452,7 @@ impl_attach_window (EphyExtension *ext,
 
 	gtk_action_group_add_toggle_actions (action_group, toggle_action_entries,
 					     G_N_ELEMENTS (toggle_action_entries),
-					     data);
+					     window);
 	gtk_ui_manager_insert_action_group (manager, action_group, -1);
 	g_object_unref (action_group);
 
@@ -461,7 +463,8 @@ impl_attach_window (EphyExtension *ext,
 			       "ViewSidebar", "ViewSidebar",
 			       GTK_UI_MANAGER_MENUITEM, FALSE);
 
-//	gtk_ui_manager_ensure_update (manager);
+	g_signal_connect (window, "notify::print-preview-mode",
+			  G_CALLBACK (window_ppv_mode_notify_cb), data);
 
 	/* Add the sidebar and the current notebook to a
 	 * GtkHPaned, and add the hpaned to where the notebook
@@ -549,7 +552,7 @@ impl_detach_window (EphyExtension *ext,
 	LOG ("EphySidebarExtension detach_window")
 
 	/* Remove UI */
-	manager = GTK_UI_MANAGER (window->ui_merge);
+	manager = GTK_UI_MANAGER (ephy_window_get_ui_manager (window));
 
 	data = (WindowData *) g_object_get_data (G_OBJECT (window), WINDOW_DATA_KEY);
 	g_return_if_fail (data != NULL);
@@ -557,6 +560,9 @@ impl_detach_window (EphyExtension *ext,
 	gtk_ui_manager_remove_ui (manager, data->merge_id);
 	gtk_ui_manager_remove_action_group (manager, data->action_group);
 
+	g_signal_handlers_disconnect_by_func
+		(window, G_CALLBACK (window_ppv_mode_notify_cb), data);
+
 	/* Remove the Sidebar, replacing our hpaned with the
 	 * notebook itself */
 	notebook = ephy_window_get_notebook (window);
